use strict;
use warnings;

use Test::NoWarnings;
use Test::Pod::Coverage 'tests' => 2;

# Test.
pod_coverage_ok('Test::Shared::Fixture::Wikibase::Datatype::Snak::Wikidata::GivenName::Douglas', 'Test::Shared::Fixture::Wikibase::Datatype::Snak::Wikidata::GivenName::Douglas is covered.');
